@@ -9,7 +9,6 @@ use crate::{
         http_types::{HttpMethod, RequestArgs, Response},
         NetworkProvider,
     },
-    StatsigErr,
 };
 
 use reqwest::Method;
@@ -60,10 +59,6 @@ impl NetworkProvider for NetworkProviderReqwest {
             headers,
         }
     }
-
-    async fn shutdown(&self) -> Result<(), StatsigErr> {
-        Ok(())
-    }
 }
 
 impl NetworkProviderReqwest {
